import asyncio
import datetime
from pytz import timezone as tz
import re

import schoolInfo.util as util


async def major(
    ATPT_OFCDC_SC_CODE: str, SD_SCHUL_CODE: str = None, auth_key: str = None
):

    addition = [f"ATPT_OFCDC_SC_CODE={ATPT_OFCDC_SC_CODE}"]

    if SD_SCHUL_CODE is not None:
        addition.append(f"SD_SCHUL_CODE={SD_SCHUL_CODE}")

    url: str = util.url_manager(
        type="schoolMajorinfo", additions=addition, auth_key=auth_key
    ).get_url()
    return (await util.HTMLGetter().get_json(url))["schoolMajorinfo"][1]["row"]



import asyncio

import schoolInfo.util as util


async def timetable(
    ATPT_OFCDC_SC_CODE: str,
    SD_SCHUL_CODE: str,
    SCHUL_KND_SC_NM: str,
    auth_key: str = None,
):
    school_type: dict = {
        "초등학교": "elsTimetable",
        "중학교": "misTimetable",
        "고등학교": "hisTimetable",
        "특수학교": "spsTimetable",
    }

    addition: list = [
        f"ATPT_OFCDC_SC_CODE={ATPT_OFCDC_SC_CODE}",
        f"SD_SCHUL_CODE={SD_SCHUL_CODE}",
    ]

    url: str = util.url_manager(
        type=school_type[SCHUL_KND_SC_NM], additions=addition, auth_key=auth_key
    ).get_url()
    return (await util.HTMLGetter().get_json(url))[school_type[SCHUL_KND_SC_NM]][1][
        "row"
    ]



import asyncio
import datetime
from pytz import timezone as tz
import re

import schoolInfo.util as util


async def meal(
    ATPT_OFCDC_SC_CODE: str,
    SD_SCHUL_CODE: str,
    MLSV_YMD: datetime.datetime = None,
    timezone: str = "Asia/Seoul",
    auth_key: str = None,
) -> dict:
    MLSV_YMD = datetime.datetime.now(tz(timezone)) if MLSV_YMD is None else MLSV_YMD
    MLSV__YMD = re.sub("[^0-9]", "", str(MLSV_YMD.__str__()))[2:8]

    addition = [
        f"MLSV_YMD={MLSV__YMD}",
        f"ATPT_OFCDC_SC_CODE={ATPT_OFCDC_SC_CODE}",
        f"SD_SCHUL_CODE={SD_SCHUL_CODE}",
    ]
    url: str = util.url_manager(
        type="mealServiceDietInfo", additions=addition, auth_key=auth_key
    ).url
    meal_data = (await util.HTMLGetter().get_json(url))["mealServiceDietInfo"][1]["row"]
    return meal_data



import asyncio

from schoolInfo.util import url_manager, HTMLGetter


async def search(keyword: str, auth_key: str = None) -> dict:
    url: str = url_manager(
        type="schoolInfo", additions=[f"SCHUL_NM={keyword}"], auth_key=auth_key
    ).get_url()
    return (await HTMLGetter().get_json(url))["schoolInfo"][1]["row"][0]



class url_manager:
    def __init__(
        self,
        type: str,
        auth_key: str = None,
        pIndex: int = 1,
        pSize: int = 100,
        additions: list = None,
    ):
        option_list: list = [f"pIndex={pIndex}", f"pSize={pSize}"]
        option: str = "&".join(option_list)

        try:
            addition_str = "&" + "&".join(additions)
        except TypeError:
            addition_str = ""

        self.url = (
            f"https://open.neis.go.kr/hub/{type}?Type=json&{option}"
            + ("" if auth_key is None else auth_key)
            + f"{addition_str}"
        )

    def get_url(self):
        return self.url



import asyncio
import datetime
import re

from schoolInfo.util import url_manager, HTMLGetter


async def schedule(
    ATPT_OFCDC_SC_CODE: str,
    SD_SCHUL_CODE: str,
    start_date: datetime.datetime = None,
    end_date: datetime.datetime = None,
    auth_key: str = None,
):
    try:
        start_date = re.sub("[^0-9]", "", str(start_date.__str__()))[2:8]
        end_date = re.sub("[^0-9]", "", str(end_date.__str__()))[2:8]
    except Exception as err:
        print(err)

    addition = [
        f"ATPT_OFCDC_SC_CODE={ATPT_OFCDC_SC_CODE}",
        f"SD_SCHUL_CODE={SD_SCHUL_CODE}",
        f"AA_FROM_YMD={start_date}" f"AA_TO_YMD={end_date}",
    ]

    url: str = url_manager(
        type="SchoolSchedule", additions=addition, auth_key=auth_key
    ).get_url()
    return (await HTMLGetter().get_json(url))["SchoolSchedule"][1]["row"]



from setuptools import setup, find_packages

setup(
    name="schoolInfo",
    version="1.0.1.1",
    url="https://github.com/sunrabbit123/school-info_python",
    author="sunrabbit123",
    author_email="qudwls185@naver.com",
    description="간단하게 Neis API를 이용해보세요!",
    packages=find_packages(exclude=["tests"]),
    long_description=open("README.md", encoding="UTF-8").read(),
    long_description_content_type="text/markdown",
    install_requires=["aiohttp", "asyncio", "pytz"],
    python_requires=">=3.6",
    zip_safe=False,
    classifiers=["License :: OSI Approved :: MIT License"],
)



import aiohttp
from bs4 import BeautifulSoup

import datetime
import random

import json
import asyncio
import re


class HTMLGetter:
    def __init__(
        self,
        headers: dict = {
            "User-Agent": "Mozilla/5.0 (Windows NT 6.3; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/63.0.3239.132 Safari/537.36"
        },
    ):
        self.headers = headers

    async def get_html(self, url: str):
        async with aiohttp.ClientSession() as cs:
            html = await cs.get(url, headers=self.headers)
            return await html.text()

    async def get_json(self, url: str):
        html = await self.get_html(url)
        data = BeautifulSoup(html, "html.parser")
        jsonData = json.loads(data.get_text())
        return jsonData



import asyncio

import schoolInfo.util as util


async def classes(ATPT_OFCDC_SC_CODE: str, SD_SCHUL_CODE: str, auth_key: str = None):

    addition: list = [
        f"ATPT_OFCDC_SC_CODE={ATPT_OFCDC_SC_CODE}",
        f"SD_SCHUL_CODE={SD_SCHUL_CODE}",
    ]

    url: str = util.url_manager(
        type="classInfo", additions=addition, auth_key=auth_key
    ).get_url()
    return (await util.HTMLGetter().get_json(url))["classInfo"][1]["row"]
